==> 1.0.0.tar.gz: jingliu-sr/README.md <==
# JingliuSR
#### Honkai: Star Rail server emulator (3.4 beta) written in Zig.

# Saber who??? trash bin who???
![Screenshot](Screenshot.png)

## Requirements
[Zig 0.13.0 x64](https://ziglang.org/download/0.13.0/zig-windows-x86_64-0.13.0.zip) and
[Proxy](https://git.xeondev.com/YYHEggEgg/FireflySR.Tool.Proxy/releases)

## Running
### From source

Windows:
```
git clone https://git.xeondev.com/HonkaiSlopRail/jingliu-sr
cd jingliu-sr
zig build run-dispatch
zig build run-
```
Then open Proxy then open client

Linux:
```
git clone https://git.xeondev.com/HonkaiSlopRail/jingliu-sr
cd jingliu-sr
zig build run-dispatch & zig build run-gameserver
```
Then open Proxy then open client

### Using Pre-built Binaries
Navigate to the [Releases](https://git.xeondev.com/HonkaiSlopRail/jingliu-sr/releases)
page and download the latest release for your platform.

## Connecting
[Get 3.3.51 client](https://gofile.io/d/tWhXrJ)

## Functionality (work in progress)
- Login and player spawn
- Test battle via calyx
- MOC/PF/AS simulator
- Gacha simulator 
- Support command for Sillyism (there are some bugs right now )

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss
what you would like to change, and why.

## Bug Reports

If you find a bug, please open an issue with as much detail as possible. If you
can, please include steps to reproduce the bug.

Bad issues such as "This doesn't work" will be closed immediately, be _sure_ to
provide exact detailed steps to reproduce your bug. If it's hard to reproduce, try
to explain it and write a reproducer as best as you can.

==> 3.0.0.tar.gz: jingliu-sr/README.md <==
# JingliuSR
#### Honkai: Star Rail server emulator (3.4 beta) written in Zig.

# Saber who??? trash bin who???
![Screenshot](Screenshot.png)

## Requirements
[Zig 0.13.0 x64](https://ziglang.org/download/0.13.0/zig-windows-x86_64-0.13.0.zip)

## Running

### Replacing mhypbase.dll

Replace [mhypbase.dll](https://git.xeondev.com/HonkaiSlopRail/jingliu-sr/raw/branch/main/mhypbase.dll) file in your game folder.

### From source

Windows:
```
git clone https://git.xeondev.com/HonkaiSlopRail/jingliu-sr
cd jingliu-sr
zig build run-dispatch
zig build run-gameserver
```
Then open your client.

Linux:
```
git clone https://git.xeondev.com/HonkaiSlopRail/jingliu-sr
cd jingliu-sr
zig build run-dispatch & zig build run-gameserver
```
Then open your client.

### Using Pre-built Binaries
Navigate to the [Releases](https://git.xeondev.com/HonkaiSlopRail/jingliu-sr/releases)
page and download the latest release for your platform.

## Connecting
[Get 3.3.51 client](https://gofile.io/d/tWhXrJ)

## Functionality (work in progress)
- Login and player spawn
- Test battle via calyx
- MOC/PF/AS simulator
- Gacha simulator 
- Support command for Sillyism

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss
what you would like to change, and why.

## Bug Reports

If you find a bug, please open an issue with as much detail as possible. If you
can, please include steps to reproduce the bug.

Bad issues such as "This doesn't work" will be closed immediately, be _sure_ to
provide exact detailed steps to reproduce your bug. If it's hard to reproduce, try
to explain it and write a reproducer as best as you can.
